@@ -216,9 +216,9 @@ Queue to put job in, defaults to C<default>.
   my $bool = $backend->fail_job(
     $job_id, $retries, {whatever => 'Something went wrong!'});
 
-Transition from C<active> to C<failed> state, and if there are attempts
-remaining, transition back to C<inactive> with a delay based on
-L<Minion/"backoff">. Meant to be overloaded in a subclass.
+Transition from C<active> to C<failed> state with or without a result, and if
+there are attempts remaining, transition back to C<inactive> with a delay based
+on L<Minion/"backoff">. Meant to be overloaded in a subclass.
 
 =head2 finish_job
 
@@ -227,8 +227,8 @@ L<Minion/"backoff">. Meant to be overloaded in a subclass.
   my $bool = $backend->finish_job(
     $job_id, $retries, {whatever => 'All went well!'});
 
-Transition from C<active> to C<finished> state. Meant to be overloaded in a
-subclass.
+Transition from C<active> to C<finished> state with or without a result. Meant
+to be overloaded in a subclass.
 
 =head2 history
 
@@ -257,6 +257,9 @@ Hourly counts for processed jobs from the past day.
 Returns the information about jobs in batches. Meant to be overloaded in a
 subclass.
 
+  # Get the total number of results (without limit)
+  my $num = $backend->list_jobs(0, 100, {queues => ['important']})->{total};
+
   # Check job state
   my $results = $backend->list_jobs(0, 1, {ids => [$job_id]});
   my $state = $results->{jobs}[0]{state};
@@ -335,6 +338,12 @@ Epoch time job was delayed to.
 
 Epoch time job was finished.
 
+=item id
+
+  id => 10025
+
+Job id.
+
 =item notes
 
   notes => {foo => 'bar', baz => [1, 2, 3]}
@@ -411,6 +420,9 @@ Id of worker that is processing the job.
 Returns information about locks in batches. Meant to be overloaded in a
 subclass.
 
+  # Get the total number of results (without limit)
+  my $num = $backend->list_locks(0, 100, {names => ['bar']})->{total};
+
   # Check expiration time
   my $results = $backend->list_locks(0, 1, {names => ['foo']});
   my $expires = $results->{locks}[0]{expires};
@@ -453,6 +465,9 @@ Lock name.
 Returns information about workers in batches. Meant to be overloaded in a
 subclass.
 
+  # Get the total number of results (without limit)
+  my $num = $backend->list_workers(0, 100)->{total};
+
   # Check worker host
   my $results = $backend->list_workers(0, 1, {ids => [$worker_id]});
   my $host    = $results->{workers}[0]{host};
@@ -473,6 +488,12 @@ These fields are currently available:
 
 =over 2
 
+=item id
+
+  id => 22
+
+Worker id.
+
 =item host
 
   host => 'localhost'
@@ -716,6 +737,6 @@ Unregister worker. Meant to be overloaded in a subclass.
 
 =head1 SEE ALSO
 
-L<Minion>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
+L<Minion>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
